@@ -45,7 +45,7 @@ class MoesifMiddlewarePre19(object):
         # below comment for setting moesif base_uri to a test server.
         if self.middleware_settings.get('LOCAL_DEBUG', False):
             Configuration.BASE_URI = self.get_configuration_uri(self.middleware_settings, 'BASE_URI', 'LOCAL_MOESIF_BASEURL')
-        Configuration.version = 'moesifdjango-python/2.1.5'
+        Configuration.version = 'moesifdjango-python/2.2.0'
         if settings.MOESIF_MIDDLEWARE.get('CAPTURE_OUTGOING_REQUESTS', False):
             try:
                 if self.DEBUG:
@@ -156,7 +156,10 @@ class MoesifMiddlewarePre19(object):
         # Code to be executed for each request before
         # the view (and later middleware) are called.
 
+        # Request time
         req_time = request.moesif_req_time
+        if self.DEBUG:
+            print("event request time: ", req_time)
 
         if self.DEBUG:
             print("raw body before getting response")
@@ -164,6 +167,10 @@ class MoesifMiddlewarePre19(object):
         # response = get_response(request)
         # Code to be executed for each request/response after
         # the view is called.
+        # Response Time
+        rsp_time = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
+        if self.DEBUG:
+            print("event response time: ", rsp_time)
 
         # Check if need to skip logging event
         skip_event_response = self.logger_helper.skip_event(request, response, self.middleware_settings, self.DEBUG)
@@ -201,9 +208,6 @@ class MoesifMiddlewarePre19(object):
                                                                                         self.LOG_BODY,
                                                                                         self.middleware_settings)
 
-        # Response Time
-        rsp_time = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3]
-
         # Prepare Event Request Model
         event_req = self.event_mapper.to_request(req_time, uri, request.method, self.api_version,
                                                  ip_address, req_headers, req_body, req_body_transfer_encoding)
